#include <Arduino.h>

#include "token.h"

// Constructor for Token class
Token::Token(int pin, float base, float limits[3], float min, float max) {
    m_pin = pin;      // Initialize pin number
    m_base = base;    // Set base value
    m_min = min;      // Set minimum value
    m_max = max;      // Set maximum value
    for(int i=0; i<3; i++) {
        m_limits[i] = limits[i];  // Copy limit values to class member array
    }
}

// Read the analog value from the sensor and calculate the adjusted value
float Token::read() {
    float valeurLue = (float)analogRead(m_pin);  // Read analog value from specified pin
    return (valeurLue * m_base) / (1023.0F - valeurLue);  // Perform scaling and return adjusted value
}

// Determine the type of token based on the read value
int Token::type() {
    float value = Token::read();  // Read the token value
    if(value < m_min || m_max < value) {
        return 0;  // Out of range, return type 0
    }
    for(int i=0; i<3; i++) {
        if(value < m_limits[i]) {
            return i + 1;  // Return type corresponding to the limit that value is less than
        }
    }
    return 4;  // Default type (in range but not matching any specific limit)
}